#!/usr/bin/perl
#=======================================================================
# FileName : cmd_GetWebRemoteControlerConfig.pl
# Summary  : Webリモコン設定取得ベースコマンド
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/24 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use JSON;
use Encode;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use CmdComFunc;
use ComLog;

our %messages = ();
my $ret = ComConst::STS_OK;

$ret = &main(@ARGV);

exit $ret;

#=======================================================================
# FuncName : main
# Summary  : Webリモコン設定取得メイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/24 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my $reqFile   = $_[0];
    my $resFile   = $_[1];
    my $requestData = "";
    my $json = "";
    my %responseData = ();
    my %conf      = ();
    my $logLevel = "";
    my $logmsg = "";
    $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_OK;
    $responseData{ComConst::JSON_KEY_MSG} = "";
    $responseData{ComConst::JSON_KEY_DAT} = ();
    my $key = "";

    # 初期化
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::initializeBaseCmd($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエスト読み込み
    if($rc == ComConst::STS_OK){
        $requestData = CmdComFunc::readRequestFile($reqFile);
    }

    # データ作成
    if($rc == ComConst::STS_OK){
        my $webRCConfigFileName = "";
        # 製品によって読み込みの設定ファイルを変える
        if($requestData->[0]->{ProductKey} eq ComConst::NORMAL_CHANNEL16){
            $webRCConfigFileName = ComConst::CHANNEL16_WEB_RC_CONFIG;
        }elsif($requestData->[0]->{ProductKey} eq ComConst::NORMAL_CHANNEL12){
            $webRCConfigFileName = ComConst::CHANNEL12_WEB_RC_CONFIG;
        }else{
            $webRCConfigFileName = ComConst::CHANNEL12_WEB_RC_CONFIG;
        }
        # 設定ファイル読み込み
         my $webRCConfig = CmdComFunc::readRequestFile($webRCConfigFileName);
         $responseData{ComConst::JSON_KEY_DAT}{WRCConfig} = $webRCConfig;
    }

    # レスポンスファイル出力
    $rc = CmdComFunc::writeResponseFile($resFile, \%responseData);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}
