#!/usr/bin/perl
package ComConst;
#=======================================================================
# FileName : ComConst.pm
# Summary  : 共通定義
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/23 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;

use constant EXEC_SYSTEM => '1';

use constant REQUEST_PATH => '../tmp';
use constant RESPONSE_PATH => '../tmp';
use constant BASE_CMD_PATH => '../bin';
use constant DATA_DIR_PATH => '../data';
use constant CONF_PATH => '../conf';
use constant MSG_PATH => '../conf/Locale/';

use constant JSON_KEY_STS => 'status';
use constant JSON_KEY_MSG => 'message';
use constant JSON_KEY_DAT => 'data';

use constant RETRY_CNT => 3;
use constant SLEEP_TIME => 1;

use constant ENCODINGS => 'utf8';

use constant NON_SETTING => "-";
use constant DEFAULT_DATE_FORMAT => '%04d%02d%02d%02d%02d%02d';

##### ステータス #####
use constant STS_OK =>  0;
use constant STS_NG => -1;
use constant STS_ERR_SES => -11;
use constant STS_ERR_FILE => -2;

##### Aileun #####
use constant AILEUN_VERSION_FILE => '/opt/aile/version.txt';
use constant GET_AILEUN_VERSION_CMD => 'head -n 1 %s';
use constant AILEUN_PRDCTNO_FILE => '/tmp/prdx2wr';
use constant GET_AILEUN_PRDCTNO_CMD => 'head -n 1 %s';
use constant SPECIAL_CONFIG_N => "";
use constant CMPRESS_AILEUN_CONFIG_CMD => '../bin/cmpressAileunConfigFiles.sh %s';
use constant AILEUN_CONFIG_ZIPFILE => 'aileun_3.zip';
use constant AILE_CONFIG_DIR => '/opt/aile/config/';
use constant AILEUN_CONFIG_CHK_CMD => '../bin/validateAileunConfigFile.sh %s';
use constant CONFIG_CHK_ST_ARG_ERR => 256;
use constant CONFIG_CHK_ST_UNZIP_ERR => 512;
use constant CONFIG_CHK_ST_REQ_ERR => 768;
use constant AILEUN_CONFIG_LOAD_CMD => '../bin/uncmpressAileunConfigFile.sh';
use constant AILEUN_PKG_FILE_NAME => 'aile.tar.gz';
use constant AILEUN_PKG_CHK_ST_ARG_ERR => 256;
use constant AILEUN_PKG_CHK_ST_VALIDATE_ERR => 1280;
use constant AILEUN_PKG_CHK_CMD => '../bin/validateAileunUpdatePackage.sh %s';
use constant AILEUN_PKG_MV_CMD => '../bin/mvAileunUpdatePackage.sh';
use constant CMPRESS_AILEUN_LOG_CMD => '../bin/cmpressAileunBackuplog.sh %s';
use constant NORMAL_CHANNEL16 => '16';
use constant NORMAL_CHANNEL12 => '12';
use constant CHANNEL16_WEB_RC_CONFIG => '../conf/16ChannelWebRemoteContolerConfig.conf';
use constant CHANNEL12_WEB_RC_CONFIG => '../conf/12ChannelWebRemoteContolerConfig.conf';
use constant AILEUN_SEND_MSG => 'id:%s,action:%s,view_no:%s,data:%s,auth:%s';
use constant FORBIDDEN_BASIC_USERS => '../conf/forbiddenUserNameList.json';
use constant FUNC_LIMITED_FILE => '/tmp/.LimitedWebFunc';

use constant TYPEKEYSYS => "sys";
use constant TYPEKEYINQ => "inq";
use constant SENDKEYNUM => "Num";
use constant SENDKEYCUR => "Cursor";
use constant SENDKEYFOCUS => "Focus";
use constant SENDKEYZOOM => "Zoom";
use constant SENDKEYPANTILT => "PanTilt";
use constant SENDKEYPOWER => "Power";

use constant SYSKEYNUMDATATEMPLATE => '{"btnId":"%s", "reqType":"key%d", "targetView":-999, "reqData":""}';
use constant SYSKEYCURDATATEMPLATE => '{"btnId":"%s", "reqType":"keyCur%s", "targetView":-999, "reqData":""}';
use constant SYSKEYOTHERDATATEMPLATE => '{"btnId":"%s", "reqType":"key%s", "targetView":-999, "reqData":""}';
use constant INQKEYDATATEMPLATE => '{"btnId":"%s", "reqType":"%s", "targetView":-999, "reqData":"", "auth":"%s"}';

# WEB-AILEUN間通信リクエストチェック
our $RequiredRequestParams = {
    "sys" => {
        "Num"    => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isNumValidValue", "defineValueKeyName"=>"", "template"=>SYSKEYNUMDATATEMPLATE},
        "Cursor" => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"%04b", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"CursorKey", "template"=>SYSKEYCURDATATEMPLATE},
        "Left"   => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Enter"  => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Menu"   => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Aster"  => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Clear"  => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
     },
    "inq" => {
        "Focus"   => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"FocusKey", "template"=>INQKEYDATATEMPLATE},
        "Zoom"    => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"ZoomKey", "template"=>INQKEYDATATEMPLATE},
        "Pantilt" => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"%04b", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"PanTiltKey", "template"=>INQKEYDATATEMPLATE},
        "Power"   => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"PowerKey", "template"=>INQKEYDATATEMPLATE},
    }
};

1;
